@@ -178,8 +178,10 @@ bool QgsGenericNumericTransformer::loadVariant( const QVariant &transformer )
 
 double QgsGenericNumericTransformer::value( double input ) const
 {
-  if ( qgsDoubleNear( mMaxValue, mMinValue ) )
-    return std::clamp( input, mMinOutput, mMaxOutput );
+  if ( mMinValue >= mMaxValue || qgsDoubleNear( mMaxValue, mMinValue ) )
+  {
+    return mMinOutput;
+  }
 
   input = transformNumeric( input );
   if ( qgsDoubleNear( mExponent, 1.0 ) )
@@ -358,6 +360,11 @@ double QgsSizeScaleTransformer::size( double value ) const
 {
   value = transformNumeric( value );
 
+  if ( mMinValue >= mMaxValue || qgsDoubleNear( mMaxValue, mMinValue ) )
+  {
+    return mMinSize;
+  }
+
   switch ( mType )
   {
     case Linear:
@@ -633,6 +640,11 @@ QString QgsColorRampTransformer::toExpression( const QString &baseExpression ) c
 
 QColor QgsColorRampTransformer::color( double value ) const
 {
+  if ( mMinValue >= mMaxValue || qgsDoubleNear( mMaxValue, mMinValue ) )
+  {
+    return mGradientRamp ? mGradientRamp->color( 0 ) : mNullColor;
+  }
+
   value = transformNumeric( value );
   double scaledVal = std::clamp( ( value - mMinValue ) / ( mMaxValue - mMinValue ), 0.0, 1.0 );
 
