@@ -47,6 +47,7 @@
 #include "qgsmarkersymbol.h"
 #include "qgslinesymbol.h"
 #include "qgspointdistancerenderer.h"
+#include "qgssldexportcontext.h"
 
 QgsGraduatedSymbolRenderer::QgsGraduatedSymbolRenderer( const QString &attrName, const QgsRangeList &ranges )
   : QgsFeatureRenderer( QStringLiteral( "graduatedSymbol" ) )
@@ -337,17 +338,30 @@ QgsGraduatedSymbolRenderer *QgsGraduatedSymbolRenderer::clone() const
 
 void QgsGraduatedSymbolRenderer::toSld( QDomDocument &doc, QDomElement &element, const QVariantMap &props ) const
 {
-  QVariantMap newProps = props;
+  QgsSldExportContext context;
+  context.setExtraProperties( props );
+  toSld( doc, element, context );
+}
+
+bool QgsGraduatedSymbolRenderer::toSld( QDomDocument &doc, QDomElement &element, QgsSldExportContext &context ) const
+{
+  const QVariantMap oldProps = context.extraProperties();
+  QVariantMap newProps = oldProps;
   newProps[ QStringLiteral( "attribute" )] = mAttrName;
   newProps[ QStringLiteral( "method" )] = graduatedMethodStr( mGraduatedMethod );
+  context.setExtraProperties( newProps );
 
   // create a Rule for each range
   bool first = true;
+  bool result = true;
   for ( QgsRangeList::const_iterator it = mRanges.constBegin(); it != mRanges.constEnd(); ++it )
   {
-    it->toSld( doc, element, newProps, first );
+    if ( !it->toSld( doc, element, mAttrName, context, first ) )
+      result = false;
     first = false;
   }
+  context.setExtraProperties( oldProps );
+  return result;
 }
 
 QgsSymbolList QgsGraduatedSymbolRenderer::symbols( QgsRenderContext &context ) const
@@ -550,7 +564,7 @@ QgsFeatureRenderer *QgsGraduatedSymbolRenderer::create( QDomElement &element, co
   QDomElement sourceColorRampElem = element.firstChildElement( QStringLiteral( "colorramp" ) );
   if ( !sourceColorRampElem.isNull() && sourceColorRampElem.attribute( QStringLiteral( "name" ) ) == QLatin1String( "[source]" ) )
   {
-    r->setSourceColorRamp( QgsSymbolLayerUtils::loadColorRamp( sourceColorRampElem ) );
+    r->setSourceColorRamp( QgsSymbolLayerUtils::loadColorRamp( sourceColorRampElem ).release() );
   }
 
   // try to load mode
@@ -924,11 +938,22 @@ void QgsGraduatedSymbolRenderer::setSymbolSizes( double minSize, double maxSize
     const double size = mRanges.count() > 1
                         ? minSize + i * ( maxSize - minSize ) / ( mRanges.count() - 1 )
                         : .5 * ( maxSize + minSize );
-    if ( symbol->type() == Qgis::SymbolType::Marker )
-      static_cast< QgsMarkerSymbol * >( symbol.get() )->setSize( size );
-    if ( symbol->type() == Qgis::SymbolType::Line )
-      static_cast< QgsLineSymbol * >( symbol.get() )->setWidth( size );
-    updateRangeSymbol( i, symbol.release() );
+    if ( symbol )
+    {
+      switch ( symbol->type() )
+      {
+        case Qgis::SymbolType::Marker:
+          static_cast< QgsMarkerSymbol * >( symbol.get() )->setSize( size );
+          break;
+        case Qgis::SymbolType::Line:
+          static_cast< QgsLineSymbol * >( symbol.get() )->setWidth( size );
+          break;
+        case Qgis::SymbolType::Fill:
+        case Qgis::SymbolType::Hybrid:
+          break;
+      }
+      updateRangeSymbol( i, symbol.release() );
+    }
   }
 }
 
