@@ -129,7 +129,7 @@ QVariant QgsFieldMappingModel::data( const QModelIndex &index, int role ) const
           }
           case ColumnDataIndex::DestinationName:
           {
-            return f.field.displayNameWithAlias();
+            return f.field.name();
           }
           case ColumnDataIndex::DestinationType:
           {
