@@ -780,7 +780,7 @@ namespace QgsWfs
         QDomNode currentAttributeChild = featureElem.firstChild();
         bool conversionSuccess = true;
 
-        while ( !currentAttributeChild.isNull() )
+        for ( ; !currentAttributeChild.isNull(); currentAttributeChild = currentAttributeChild.nextSibling() )
         {
           QDomElement currentAttributeElement = currentAttributeChild.toElement();
           QString attrName = currentAttributeElement.localName();
@@ -792,6 +792,7 @@ namespace QgsWfs
               fieldMapIt = fieldMap.find( attrName );
               if ( fieldMapIt == fieldMap.constEnd() )
               {
+                QgsMessageLog::logMessage( QStringLiteral( "Skipping unknown attribute: name=%1" ).arg( attrName ) );
                 continue;
               }
 
@@ -824,7 +825,6 @@ namespace QgsWfs
               feat.setGeometry( g );
             }
           }
-          currentAttributeChild = currentAttributeChild.nextSibling();
         }
         // update feature list
         featList << feat;
@@ -891,7 +891,7 @@ namespace QgsWfs
         }
 
         QMap<QString, QStringList>::const_iterator fidsMapIt = fidsMap.constBegin();
-        while ( fidsMapIt != fidsMap.constEnd() )
+        for ( ; fidsMapIt != fidsMap.constEnd(); ++fidsMapIt )
         {
           transactionDelete action;
           action.typeName = fidsMapIt.key();
@@ -1202,7 +1202,7 @@ namespace QgsWfs
       action.typeName = typeName;
       action.propertyMap = propertyMap;
       action.geometryElement = geometryElem;
-      action.featureRequest = featureRequest;
+      action.featureRequest = std::move( featureRequest );
       action.serverFids = serverFids;
       action.error = false;
 
